Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/server.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorMorris Jobke <hey@morrisjobke.de>2015-06-17 12:10:55 +0300
committerMorris Jobke <hey@morrisjobke.de>2015-06-17 17:55:21 +0300
commit7759a9118cfd30bf94593cfe350108f573fb3644 (patch)
tree57f9160fe3620428db2e8e333f95e8c142e21dcc /lib
parent6ea7e89649896763b0f8bb927cadee3f38eb3a36 (diff)
Fix OCP PHPDoc
* was always a string instead of \OCP\IUser
Diffstat (limited to 'lib')
-rw-r--r--lib/public/iservercontainer.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/public/iservercontainer.php b/lib/public/iservercontainer.php
index 193e2fdf105..a0cccc07ac8 100644
--- a/lib/public/iservercontainer.php
+++ b/lib/public/iservercontainer.php
@@ -251,11 +251,11 @@ interface IServerContainer {
/**
* Get the certificate manager for the user
*
* @param \OCP\IUser $user (optional) if not specified the current loggedin user is used
* @return \OCP\ICertificateManager
*/
- function getCertificateManager($user = null);
-
+ function getCertificateManager($userId = null);
+
/**
* Create a new event source
*
@@ -251,11 +251,11 @@ interface IServerContainer {
* Get the certificate manager for the user
*
- * @param \OCP\IUser $user (optional) if not specified the current loggedin user is used
+ * @param string $userId (optional) if not specified the current loggedin user is used
* @return \OCP\ICertificateManager
*/